PyXMake Developer Guide: PyXMake.Tools.Utility.AbstractMethod Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
PyXMake.Tools.Utility.AbstractMethod Class Reference

Class to create 2to3 compatible pickling dictionary. More...

Inheritance diagram for PyXMake.Tools.Utility.AbstractMethod:

## Public Member Functions
| __init__ (self, method)
| __get__ (self, obj=None, objtype=None)

## Public Attributes
| method = method

## Detailed Description

Class to create 2to3 compatible pickling dictionary.

    Abstract method to construct an instance and class method with the same descriptor.

    @note: Derived from https://stackoverflow.com/questions/2589690/creating-a-method-that-is-simultaneously-an-instance-and-class-method

Inherited from built-in object.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Tools.Utility.AbstractMethod.__init__ | ( |  | self,
|  |  | method )

    Construct an instance method.

Definition at line 272 of file Utility.py.

## Member Function Documentation

## ◆ __get__()

PyXMake.Tools.Utility.AbstractMethod.__get__ | ( |  | self,
|  |  | obj = None,
|  |  | objtype = None )

    Custom descriptor for this class. Returns method either as class or as an instance.

Definition at line 278 of file Utility.py.

## Member Data Documentation

## ◆ method

PyXMake.Tools.Utility.AbstractMethod.method = method

Definition at line 276 of file Utility.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Tools/Utility.py